Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1251)

Unified Diff: chrome/browser/views/appcache_info_view.h

Issue 650110: Teach the cookie tree view / model about appcaches. Not hooked up to real dat... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 10 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/mock_browsing_data_appcache_helper.cc ('k') | chrome/browser/views/appcache_info_view.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/views/appcache_info_view.h
===================================================================
--- chrome/browser/views/appcache_info_view.h (revision 39380)
+++ chrome/browser/views/appcache_info_view.h (working copy)
@@ -2,58 +2,51 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_VIEWS_LOCAL_STORAGE_INFO_VIEW_H_
-#define CHROME_BROWSER_VIEWS_LOCAL_STORAGE_INFO_VIEW_H_
+#ifndef CHROME_BROWSER_VIEWS_APPCACHE_INFO_VIEW_H_
+#define CHROME_BROWSER_VIEWS_APPCACHE_INFO_VIEW_H_
#include <string>
#include <vector>
#include "views/view.h"
-#include "chrome/browser/browsing_data_local_storage_helper.h"
+#include "chrome/browser/browsing_data_appcache_helper.h"
namespace views {
+class GridLayout;
class Label;
class Textfield;
}
///////////////////////////////////////////////////////////////////////////////
-// LocalStorageInfoView
+// AppCacheInfoView
//
-// Responsible for displaying a tabular grid of Local Storage information.
-class LocalStorageInfoView : public views::View {
+// Responsible for displaying a tabular grid of AppCache information.
+class AppCacheInfoView : public views::View {
public:
- LocalStorageInfoView();
- virtual ~LocalStorageInfoView();
+ AppCacheInfoView();
+ virtual ~AppCacheInfoView();
- // Update the display from the specified Local Storage info.
- void SetLocalStorageInfo(
- const BrowsingDataLocalStorageHelper::LocalStorageInfo&
- local_storage_info);
+ void SetAppCacheInfo(const BrowsingDataAppCacheHelper::AppCacheInfo* info);
+ void ClearAppCacheDisplay();
+ void EnableAppCacheDisplay(bool enabled);
- // Clears the cookie display to indicate that no or multiple local storages
- // are selected.
- void ClearLocalStorageDisplay();
-
- // Enables or disables the local storate property text fields.
- void EnableLocalStorageDisplay(bool enabled);
-
protected:
// views::View overrides:
virtual void ViewHierarchyChanged(
bool is_add, views::View* parent, views::View* child);
private:
- // Set up the view layout
void Init();
+ void AddRow(int layout_id, views::GridLayout* layout, views::Label* label,
+ views::Textfield* field, bool add_padding_row);
- // Individual property labels
- views::Textfield* origin_value_field_;
- views::Textfield* size_value_field_;
- views::Textfield* last_modified_value_field_;
+ views::Textfield* manifest_url_field_;
+ views::Textfield* size_field_;
+ views::Textfield* creation_date_field_;
+ views::Textfield* last_access_field_;
- DISALLOW_COPY_AND_ASSIGN(LocalStorageInfoView);
+ DISALLOW_COPY_AND_ASSIGN(AppCacheInfoView);
};
+#endif // CHROME_BROWSER_VIEWS_APPCACHE_INFO_VIEW_H_
-#endif // CHROME_BROWSER_VIEWS_LOCAL_STORAGE_INFO_VIEW_H_
-
« no previous file with comments | « chrome/browser/mock_browsing_data_appcache_helper.cc ('k') | chrome/browser/views/appcache_info_view.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698